@@ -72,7 +72,7 @@ def create_client_from_env(username=None,
 
         >>> import SoftLayer
         >>> client = SoftLayer.create_client_from_env()
-        >>> resp = client['Account'].getObject()
+        >>> resp = client.call('Account', 'getObject')
         >>> resp['companyName']
         'Your Company'
 
@@ -95,11 +95,21 @@ def create_client_from_env(username=None,
 
     # If we have enough information to make an auth driver, let's do it
     if auth is None and settings.get('username') and settings.get('api_key'):
+        # NOTE(kmcdonald): some transports mask other transports, so this is
+        # a way to find the 'real' one
+        real_transport = getattr(transport, 'transport', transport)
 
-        auth = slauth.BasicAuthentication(
-            settings.get('username'),
-            settings.get('api_key'),
-        )
+        if isinstance(real_transport, transports.XmlRpcTransport):
+            auth = slauth.BasicAuthentication(
+                settings.get('username'),
+                settings.get('api_key'),
+            )
+
+        elif isinstance(real_transport, transports.RestTransport):
+            auth = slauth.BasicHTTPAuthentication(
+                settings.get('username'),
+                settings.get('api_key'),
+            )
 
     return BaseClient(auth=auth, transport=transport)
 
@@ -141,11 +151,11 @@ class BaseClient(object):
 
         """
         self.auth = None
-        res = self['User_Customer'].getPortalLoginToken(
-            username,
-            password,
-            security_question_id,
-            security_question_answer)
+        res = self.call('User_Customer', 'getPortalLoginToken',
+                        username,
+                        password,
+                        security_question_id,
+                        security_question_answer)
         self.auth = slauth.TokenAuthentication(res['userId'], res['hash'])
         return res['userId'], res['hash']
 
@@ -177,7 +187,7 @@ class BaseClient(object):
         Usage:
             >>> import SoftLayer
             >>> client = SoftLayer.create_client_from_env()
-            >>> client['Account'].getVirtualGuests(mask="id", limit=10)
+            >>> client.call('Account', 'getVirtualGuests', mask="id", limit=10)
             [...]
 
         """
@@ -344,7 +354,7 @@ class Service(object):
         Usage:
             >>> import SoftLayer
             >>> client = SoftLayer.create_client_from_env()
-            >>> gen = client['Account'].getVirtualGuests(iter=True)
+            >>> gen = client.call('Account', 'getVirtualGuests', iter=True)
             >>> for virtual_guest in gen:
             ...     virtual_guest['id']
             ...
