@@ -11,26 +11,25 @@ ALL_ROUTES = [
 
     ('call-api', 'SoftLayer.CLI.call_api:cli'),
 
-    ('vs', 'SoftLayer.CLI.virt'),
-    ('vs:cancel', 'SoftLayer.CLI.virt.cancel:cli'),
-    ('vs:capture', 'SoftLayer.CLI.virt.capture:cli'),
-    ('vs:create', 'SoftLayer.CLI.virt.create:cli'),
-    ('vs:create-options', 'SoftLayer.CLI.virt.create_options:cli'),
-    ('vs:detail', 'SoftLayer.CLI.virt.detail:cli'),
-    ('vs:dns-sync', 'SoftLayer.CLI.virt.dns:cli'),
-    ('vs:edit', 'SoftLayer.CLI.virt.edit:cli'),
-    ('vs:list', 'SoftLayer.CLI.virt.list:cli'),
-    ('vs:network', 'SoftLayer.CLI.virt.network:cli'),
-    ('vs:pause', 'SoftLayer.CLI.virt.power:pause'),
-    ('vs:power_off', 'SoftLayer.CLI.virt.power:power_off'),
-    ('vs:power_on', 'SoftLayer.CLI.virt.power:power_on'),
-    ('vs:rescue', 'SoftLayer.CLI.virt.power:rescue'),
-    ('vs:resume', 'SoftLayer.CLI.virt.power:resume'),
-    ('vs:ready', 'SoftLayer.CLI.virt.ready:cli'),
-    ('vs:reboot', 'SoftLayer.CLI.virt.power:reboot'),
-    ('vs:reload', 'SoftLayer.CLI.virt.reload:cli'),
-    ('vs:upgrade', 'SoftLayer.CLI.virt.upgrade:cli'),
-    ('vs:credentials', 'SoftLayer.CLI.virt.credentials:cli'),
+    ('virtual', 'SoftLayer.CLI.virt'),
+    ('virtual:cancel', 'SoftLayer.CLI.virt.cancel:cli'),
+    ('virtual:capture', 'SoftLayer.CLI.virt.capture:cli'),
+    ('virtual:create', 'SoftLayer.CLI.virt.create:cli'),
+    ('virtual:create-options', 'SoftLayer.CLI.virt.create_options:cli'),
+    ('virtual:detail', 'SoftLayer.CLI.virt.detail:cli'),
+    ('virtual:dns-sync', 'SoftLayer.CLI.virt.dns:cli'),
+    ('virtual:edit', 'SoftLayer.CLI.virt.edit:cli'),
+    ('virtual:list', 'SoftLayer.CLI.virt.list:cli'),
+    ('virtual:pause', 'SoftLayer.CLI.virt.power:pause'),
+    ('virtual:power-off', 'SoftLayer.CLI.virt.power:power_off'),
+    ('virtual:power-on', 'SoftLayer.CLI.virt.power:power_on'),
+    ('virtual:rescue', 'SoftLayer.CLI.virt.power:rescue'),
+    ('virtual:resume', 'SoftLayer.CLI.virt.power:resume'),
+    ('virtual:ready', 'SoftLayer.CLI.virt.ready:cli'),
+    ('virtual:reboot', 'SoftLayer.CLI.virt.power:reboot'),
+    ('virtual:reload', 'SoftLayer.CLI.virt.reload:cli'),
+    ('virtual:upgrade', 'SoftLayer.CLI.virt.upgrade:cli'),
+    ('virtual:credentials', 'SoftLayer.CLI.virt.credentials:cli'),
 
     ('cdn', 'SoftLayer.CLI.cdn'),
     ('cdn:detail', 'SoftLayer.CLI.cdn.detail:cli'),
@@ -57,6 +56,15 @@ ALL_ROUTES = [
     ('dns:zone-list', 'SoftLayer.CLI.dns.zone_list:cli'),
     ('dns:zone-print', 'SoftLayer.CLI.dns.zone_print:cli'),
 
+    ('block', 'SoftLayer.CLI.block'),
+    ('block:volume-list', 'SoftLayer.CLI.block.list:cli'),
+    ('block:volume-detail', 'SoftLayer.CLI.block.detail:cli'),
+    ('block:volume-cancel', 'SoftLayer.CLI.block.cancel:cli'),
+    ('block:volume-order', 'SoftLayer.CLI.block.order:cli'),
+    ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot_list:cli'),
+    ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot_delete:cli'),
+    ('block:access-list', 'SoftLayer.CLI.block.access_list:cli'),
+
     ('firewall', 'SoftLayer.CLI.firewall'),
     ('firewall:add', 'SoftLayer.CLI.firewall.add:cli'),
     ('firewall:cancel', 'SoftLayer.CLI.firewall.cancel:cli'),
@@ -77,6 +85,7 @@ ALL_ROUTES = [
     ('image:edit', 'SoftLayer.CLI.image.edit:cli'),
     ('image:list', 'SoftLayer.CLI.image.list:cli'),
     ('image:import', 'SoftLayer.CLI.image.import:cli'),
+    ('image:export', 'SoftLayer.CLI.image.export:cli'),
 
     ('iscsi', 'SoftLayer.CLI.iscsi'),
     ('iscsi:cancel', 'SoftLayer.CLI.iscsi.cancel:cli'),
@@ -127,26 +136,31 @@ ALL_ROUTES = [
     ('nas:list', 'SoftLayer.CLI.nas.list:cli'),
     ('nas:credentials', 'SoftLayer.CLI.nas.credentials:cli'),
 
+    ('object-storage', 'SoftLayer.CLI.object_storage'),
+    ('object-storage:accounts',
+     'SoftLayer.CLI.object_storage.list_accounts:cli'),
+    ('object-storage:endpoints',
+     'SoftLayer.CLI.object_storage.list_endpoints:cli'),
+
     ('rwhois', 'SoftLayer.CLI.rwhois'),
     ('rwhois:edit', 'SoftLayer.CLI.rwhois.edit:cli'),
     ('rwhois:show', 'SoftLayer.CLI.rwhois.show:cli'),
 
-    ('server', 'SoftLayer.CLI.server'),
-    ('server:cancel', 'SoftLayer.CLI.server.cancel:cli'),
-    ('server:cancel-reasons', 'SoftLayer.CLI.server.cancel_reasons:cli'),
-    ('server:create', 'SoftLayer.CLI.server.create:cli'),
-    ('server:create-options', 'SoftLayer.CLI.server.create_options:cli'),
-    ('server:detail', 'SoftLayer.CLI.server.detail:cli'),
-    ('server:edit', 'SoftLayer.CLI.server.edit:cli'),
-    ('server:list', 'SoftLayer.CLI.server.list:cli'),
-    ('server:nic-edit', 'SoftLayer.CLI.server.nic_edit:cli'),
-    ('server:power-cycle', 'SoftLayer.CLI.server.power:power_cycle'),
-    ('server:power-off', 'SoftLayer.CLI.server.power:power_off'),
-    ('server:power-on', 'SoftLayer.CLI.server.power:power_on'),
-    ('server:reboot', 'SoftLayer.CLI.server.power:reboot'),
-    ('server:reload', 'SoftLayer.CLI.server.reload:cli'),
-    ('server:credentials', 'SoftLayer.CLI.server.credentials:cli'),
-    ('server:update-firmware', 'SoftLayer.CLI.server.update_firmware:cli'),
+    ('hardware', 'SoftLayer.CLI.hardware'),
+    ('hardware:cancel', 'SoftLayer.CLI.hardware.cancel:cli'),
+    ('hardware:cancel-reasons', 'SoftLayer.CLI.hardware.cancel_reasons:cli'),
+    ('hardware:create', 'SoftLayer.CLI.hardware.create:cli'),
+    ('hardware:create-options', 'SoftLayer.CLI.hardware.create_options:cli'),
+    ('hardware:detail', 'SoftLayer.CLI.hardware.detail:cli'),
+    ('hardware:edit', 'SoftLayer.CLI.hardware.edit:cli'),
+    ('hardware:list', 'SoftLayer.CLI.hardware.list:cli'),
+    ('hardware:power-cycle', 'SoftLayer.CLI.hardware.power:power_cycle'),
+    ('hardware:power-off', 'SoftLayer.CLI.hardware.power:power_off'),
+    ('hardware:power-on', 'SoftLayer.CLI.hardware.power:power_on'),
+    ('hardware:reboot', 'SoftLayer.CLI.hardware.power:reboot'),
+    ('hardware:reload', 'SoftLayer.CLI.hardware.reload:cli'),
+    ('hardware:credentials', 'SoftLayer.CLI.hardware.credentials:cli'),
+    ('hardware:update-firmware', 'SoftLayer.CLI.hardware.update_firmware:cli'),
 
     ('snapshot', 'SoftLayer.CLI.snapshot'),
     ('snapshot:cancel', 'SoftLayer.CLI.snapshot.cancel:cli'),
@@ -183,6 +197,8 @@ ALL_ROUTES = [
     ('ticket:update', 'SoftLayer.CLI.ticket.update:cli'),
     ('ticket:subjects', 'SoftLayer.CLI.ticket.subjects:cli'),
     ('ticket:summary', 'SoftLayer.CLI.ticket.summary:cli'),
+    ('ticket:attach', 'SoftLayer.CLI.ticket.attach:cli'),
+    ('ticket:detach', 'SoftLayer.CLI.ticket.detach:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
@@ -192,12 +208,11 @@ ALL_ROUTES = [
 ]
 
 ALL_ALIASES = {
+    'hw': 'hardware',
+    'lb': 'loadbal',
     'meta': 'metadata',
     'my': 'metadata',
-    'vm': 'vs',
-    'hardware': 'server',
-    'hw': 'server',
-    'bmetal': 'bmc',
-    'virtual': 'vs',
-    'lb': 'loadbal',
+    'server': 'hardware',
+    'vm': 'virtual',
+    'vs': 'virtual',
 }
