@@ -269,15 +269,17 @@ class HardwareManager(utils.IdentifierMixin, object):
 
             #change the Public interface to 10Mbps on instance 12345
             result = mgr.change_port_speed(hardware_id=12345,
-                                        public=True, speed=10)
+                                           public=True, speed=10)
             # result will be True or an Exception
         """
         if public:
-            func = self.hardware.setPublicNetworkInterfaceSpeed
+            return self.client.call('Hardware_Server',
+                                    'setPublicNetworkInterfaceSpeed',
+                                    speed, id=hardware_id)
         else:
-            func = self.hardware.setPrivateNetworkInterfaceSpeed
-
-        return func(speed, id=hardware_id)
+            return self.client.call('Hardware_Server',
+                                    'setPrivateNetworkInterfaceSpeed',
+                                    speed, id=hardware_id)
 
     def place_order(self, **kwargs):
         """Places an order for a piece of hardware.
@@ -363,7 +365,10 @@ class HardwareManager(utils.IdentifierMixin, object):
         port_speeds = []
         for item in package['items']:
             if all([item['itemCategory']['categoryCode'] == 'port_speed',
-                    not _is_private_port_speed_item(item)]):
+                    # Hide private options
+                    not _is_private_port_speed_item(item),
+                    # Hide unbonded options
+                    _is_bonded(item)]):
                 port_speeds.append({
                     'name': item['description'],
                     'key': item['capacity'],
@@ -573,7 +578,7 @@ def _get_extra_price_id(items, key_name, hourly, location):
     """Returns a price id attached to item with the given key_name."""
 
     for item in items:
-        if not utils.lookup(item, 'keyName') == key_name:
+        if utils.lookup(item, 'keyName') != key_name:
             continue
 
         for price in item['prices']:
@@ -593,7 +598,7 @@ def _get_default_price_id(items, option, hourly, location):
     """Returns a 'free' price id given an option."""
 
     for item in items:
-        if not utils.lookup(item, 'itemCategory', 'categoryCode') == option:
+        if utils.lookup(item, 'itemCategory', 'categoryCode') != option:
             continue
 
         for price in item['prices']:
@@ -618,9 +623,9 @@ def _get_bandwidth_price_id(items,
 
         capacity = float(item.get('capacity', 0))
         # Hourly and private only do pay-as-you-go bandwidth
-        if any([not utils.lookup(item,
-                                 'itemCategory',
-                                 'categoryCode') == 'bandwidth',
+        if any([utils.lookup(item,
+                             'itemCategory',
+                             'categoryCode') != 'bandwidth',
                 (hourly or no_public) and capacity != 0.0,
                 not (hourly or no_public) and capacity == 0.0]):
             continue
@@ -641,12 +646,12 @@ def _get_os_price_id(items, os, location):
     """Returns the price id matching."""
 
     for item in items:
-        if any([not utils.lookup(item,
-                                 'itemCategory',
-                                 'categoryCode') == 'os',
-                not utils.lookup(item,
-                                 'softwareDescription',
-                                 'referenceCode') == os]):
+        if any([utils.lookup(item,
+                             'itemCategory',
+                             'categoryCode') != 'os',
+                utils.lookup(item,
+                             'softwareDescription',
+                             'referenceCode') != os]):
             continue
 
         for price in item['prices']:
@@ -663,14 +668,15 @@ def _get_port_speed_price_id(items, port_speed, no_public, location):
     """Choose a valid price id for port speed."""
 
     for item in items:
-        if not utils.lookup(item,
-                            'itemCategory',
-                            'categoryCode') == 'port_speed':
+        if utils.lookup(item,
+                        'itemCategory',
+                        'categoryCode') != 'port_speed':
             continue
 
         # Check for correct capacity and if the item matches private only
         if any([int(utils.lookup(item, 'capacity')) != port_speed,
-                _is_private_port_speed_item(item) != no_public]):
+                _is_private_port_speed_item(item) != no_public,
+                not _is_bonded(item)]):
             continue
 
         for price in item['prices']:
@@ -713,6 +719,15 @@ def _is_private_port_speed_item(item):
     return False
 
 
+def _is_bonded(item):
+    """Determine if the item refers to a bonded port."""
+    for attribute in item['attributes']:
+        if attribute['attributeTypeKeyName'] == 'NON_LACP':
+            return False
+
+    return True
+
+
 def _get_location(package, location):
     """Get the longer key with a short location name."""
     for region in package['regions']:
