@@ -5,6 +5,7 @@
 
     :license: MIT, see LICENSE for more details.
 """
+import collections
 
 from SoftLayer import exceptions
 from SoftLayer import utils
@@ -13,14 +14,24 @@ DEFAULT_SUBNET_MASK = ','.join(['hardware',
                                 'datacenter',
                                 'ipAddressCount',
                                 'virtualGuests'])
-DEFAULT_VLAN_MASK = ','.join(['firewallInterfaces',
-                              'hardware',
-                              'networkComponents',
-                              'primaryRouter'  # Lack of comma intential
-                              '[id, fullyQualifiedDomainName, datacenter]',
-                              'subnets',
-                              'totalPrimaryIpAddressCount',
-                              'virtualGuests'])
+DEFAULT_VLAN_MASK = ','.join([
+    'firewallInterfaces',
+    'hardwareCount',
+    'primaryRouter[id, fullyQualifiedDomainName, datacenter]',
+    'subnetCount',
+    'totalPrimaryIpAddressCount',
+    'virtualGuestCount',
+    'networkSpace',
+])
+DEFAULT_GET_VLAN_MASK = ','.join([
+    'firewallInterfaces',
+    'primaryRouter[id, fullyQualifiedDomainName, datacenter]',
+    'totalPrimaryIpAddressCount',
+    'networkSpace',
+    'hardware',
+    'subnets',
+    'virtualGuests',
+])
 
 
 class NetworkManager(object):
@@ -205,7 +216,7 @@ class NetworkManager(object):
                   the specified VLAN.
 
         """
-        return self.vlan.getObject(id=vlan_id, mask=DEFAULT_VLAN_MASK)
+        return self.vlan.getObject(id=vlan_id, mask=DEFAULT_GET_VLAN_MASK)
 
     def list_global_ips(self, version=None, identifier=None, **kwargs):
         """Returns a list of all global IP address records on the account.
@@ -333,45 +344,30 @@ class NetworkManager(object):
                   other objects residing within that data center.
 
         """
-        datacenters = {}
-        unique_vms = []
-        unique_servers = []
-        unique_network = []
+        datacenters = collections.defaultdict(lambda: {
+            'hardware_count': 0,
+            'public_ip_count': 0,
+            'subnet_count': 0,
+            'virtual_guest_count': 0,
+            'vlan_count': 0,
+        })
 
         for vlan in self.list_vlans():
             name = utils.lookup(vlan, 'primaryRouter', 'datacenter', 'name')
-            if name not in datacenters:
-                datacenters[name] = {
-                    'hardwareCount': 0,
-                    'networkingCount': 0,
-                    'primaryIpCount': 0,
-                    'subnetCount': 0,
-                    'virtualGuestCount': 0,
-                    'vlanCount': 0,
-                }
 
-            datacenters[name]['vlanCount'] += 1
-
-            for hardware in vlan['hardware']:
-                if hardware['id'] not in unique_servers:
-                    datacenters[name]['hardwareCount'] += 1
-                    unique_servers.append(hardware['id'])
-
-            for net in vlan['networkComponents']:
-                if net['id'] not in unique_network:
-                    datacenters[name]['networkingCount'] += 1
-                    unique_network.append(net['id'])
-
-            for virtual_guest in vlan['virtualGuests']:
-                if virtual_guest['id'] not in unique_vms:
-                    datacenters[name]['virtualGuestCount'] += 1
-                    unique_vms.append(virtual_guest['id'])
-
-            datacenters[name]['primaryIpCount'] += (
+            datacenters[name]['vlan_count'] += 1
+            datacenters[name]['public_ip_count'] += (
                 vlan['totalPrimaryIpAddressCount'])
-            datacenters[name]['subnetCount'] += len(vlan['subnets'])
+            datacenters[name]['subnet_count'] += vlan['subnetCount']
 
-        return datacenters
+            # NOTE(kmcdonald): Only count hardware/guests once
+            if vlan.get('networkSpace') == 'PRIVATE':
+                datacenters[name]['hardware_count'] += (
+                    vlan['hardwareCount'])
+                datacenters[name]['virtual_guest_count'] += (
+                    vlan['virtualGuestCount'])
+
+        return dict(datacenters)
 
     def unassign_global_ip(self, global_ip_id):
         """Unassigns a global IP address from a target.
